containertools.Cluster
======================

.. inheritance-diagram:: abjad.tools.containertools.Cluster.Cluster.Cluster
   :private-bases:

.. autoclass:: abjad.tools.containertools.Cluster.Cluster.Cluster

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.containertools.Cluster.Cluster.Cluster.contents_duration

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. autoattribute:: abjad.tools.containertools.Cluster.Cluster.Cluster.duration_in_seconds

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. autoattribute:: abjad.tools.containertools.Cluster.Cluster.Cluster.format

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.containertools.Cluster.Cluster.Cluster.leaves

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. autoattribute:: abjad.tools.containertools.Cluster.Cluster.Cluster.marks

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.containertools.Cluster.Cluster.Cluster.music

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. autoattribute:: abjad.tools.containertools.Cluster.Cluster.Cluster.override

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.containertools.Cluster.Cluster.Cluster.parent

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.containertools.Cluster.Cluster.Cluster.preprolated_duration

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. autoattribute:: abjad.tools.containertools.Cluster.Cluster.Cluster.prolated_duration

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.containertools.Cluster.Cluster.Cluster.prolation

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.containertools.Cluster.Cluster.Cluster.set

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.containertools.Cluster.Cluster.Cluster.spanners

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.containertools.Cluster.Cluster.Cluster.is_parallel

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

Methods
-------

.. automethod:: abjad.tools.containertools.Cluster.Cluster.Cluster.append

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.containertools.Cluster.Cluster.Cluster.extend

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.containertools.Cluster.Cluster.Cluster.index

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.containertools.Cluster.Cluster.Cluster.insert

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.containertools.Cluster.Cluster.Cluster.pop

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.containertools.Cluster.Cluster.Cluster.remove

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

Special Methods
---------------

.. automethod:: abjad.tools.containertools.Cluster.Cluster.Cluster.__add__

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.containertools.Cluster.Cluster.Cluster.__contains__

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.containertools.Cluster.Cluster.Cluster.__delattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.containertools.Cluster.Cluster.Cluster.__delitem__

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.containertools.Cluster.Cluster.Cluster.__eq__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.containertools.Cluster.Cluster.Cluster.__ge__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.containertools.Cluster.Cluster.Cluster.__getitem__

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.containertools.Cluster.Cluster.Cluster.__gt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.containertools.Cluster.Cluster.Cluster.__hash__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.containertools.Cluster.Cluster.Cluster.__iadd__

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.containertools.Cluster.Cluster.Cluster.__imul__

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.containertools.Cluster.Cluster.Cluster.__le__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.containertools.Cluster.Cluster.Cluster.__len__

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.containertools.Cluster.Cluster.Cluster.__lt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.containertools.Cluster.Cluster.Cluster.__mul__

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. automethod:: abjad.tools.containertools.Cluster.Cluster.Cluster.__ne__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.containertools.Cluster.Cluster.Cluster.__radd__

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.containertools.Cluster.Cluster.Cluster.__repr__

.. automethod:: abjad.tools.containertools.Cluster.Cluster.Cluster.__rmul__

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. automethod:: abjad.tools.containertools.Cluster.Cluster.Cluster.__setattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.containertools.Cluster.Cluster.Cluster.__setitem__

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.containertools.Cluster.Cluster.Cluster.__str__

   .. note:: Inherited from `__builtin__.object`
